@@ -1,5 +1,5 @@
 package Tangerine;
-$Tangerine::VERSION = '0.16';
+$Tangerine::VERSION = '0.17';
 # ABSTRACT: Examine perl files and report dependency metadata
 use 5.010;
 use strict;
@@ -219,6 +219,10 @@ Deprecated.  These are provided for backwards compatibility only.
 
 L<Tangerine::Occurence>
 
+=head1 REPOSITORY
+
+L<https://github.com/contyk/tangerine.pm>
+
 =head1 AUTHOR
 
 Petr Šabata <contyk@redhat.com>
